/**
 * Ultrasonic sensor uses NewPing library
 * https://bitbucket.org/teckel12/arduino-new-ping/wiki/Home
 * 
 * The sketch in the attachment is a replacement which uses the Serial Monitor for output.
 * So you can see the values on your computer, instead of on the display.
 * You start the Serial Monitor (after a succesful upload) via Tools > Serial Monitor, or the icon in the top right corner.
 */

#include <NewPing.h>

#define TRIGGER_PIN  4  // Arduino pin tied to trigger pin on the ultrasonic sensor.
#define ECHO_PIN     5  // Arduino pin tied to echo pin on the ultrasonic sensor.
#define MAX_DISTANCE 300 // Maximum distance we want to ping for (in centimeters). Maximum sensor distance is rated at 400-500cm.

NewPing sonar(TRIGGER_PIN, ECHO_PIN, MAX_DISTANCE); // NewPing setup of pins and maximum distance.

void setup() {
  Serial.begin(9600); // start serial port output, check for same speed at Serial Monitor
}

void loop() {
  unsigned int distance = sonar.convert_cm(sonar.ping_median(5)); // read distance from ultrasonic sensor (using median of 5 iterations)
  // display value in serial monitor:
  Serial.print("Distance: ");
  Serial.println(distance);

  delay(500); // wait half a second
}
